@@ -1,3 +1,17 @@
+# Copyright 2021 cstsunfu. All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from typing import Dict
 import torch.nn as nn
 from dlk.utils.config import BaseConfig
@@ -8,13 +22,15 @@ import torch.optim as optim
 
 @scheduler_config_register("constant")
 class ConstantScheduleConfig(BaseConfig):
-    """
-    {
-        "config": {
-            "last_epoch": -1
-        },
-        "_name": "constant",
-    }
+    """Config for ConstantSchedule
+
+    Config Example:
+        >>> {
+        >>>     "config": {
+        >>>         "last_epoch": -1
+        >>>     },
+        >>>     "_name": "constant",
+        >>> }
     """
     def __init__(self, config: Dict):
         super(ConstantScheduleConfig, self).__init__(config)
@@ -27,13 +43,18 @@ class ConstantScheduleConfig(BaseConfig):
 
 @scheduler_register("constant")
 class ConstantSchedule(BaseScheduler):
+    """no schedule
+    """
     def __init__(self, optimizer: optim.Optimizer, config: ConstantScheduleConfig):
         super(ConstantSchedule, self).__init__()
         self.config = config
         self.optimizer = optimizer
 
     def get_scheduler(self):
-        """TODO: Docstring for get_scheduler.
-        :returns: TODO
+        """return the initialized constant scheduler
+
+        Returns: 
+            Schedule
+
         """
         return LambdaLR(self.optimizer, lambda _: 1, last_epoch=self.config.last_epoch)
