@@ -19,6 +19,7 @@ from typing import Dict, Callable, Set, List
 from dlk.data.subprocessors import subprocessor_register, subprocessor_config_register, ISubProcessor
 from functools import partial
 from dlk.utils.logger import Logger
+import os
 import pandas as pd
 
 logger = Logger.get_logger()
@@ -123,9 +124,14 @@ class SeqLabRelabel(ISubProcessor):
                 logger.info(f'The {data_set_name} not in data. We will skip do seq_lab_relabel on it.')
                 continue
             data_set = data['data'][data_set_name]
-            data_set[[self.config.output_labels,
-                self.config.entities_info
-            ]] = data_set.parallel_apply(self.relabel, axis=1, result_type='expand')
+            if os.environ.get('DISABLE_PANDAS_PARALLEL', 'false') != 'false':
+                data_set[[self.config.output_labels,
+                    self.config.entities_info
+                ]] = data_set.parallel_apply(self.relabel, axis=1, result_type='expand')
+            else:
+                data_set[[self.config.output_labels,
+                    self.config.entities_info
+                ]] = data_set.apply(self.relabel, axis=1, result_type='expand')
 
         return data
 
